<?php

/**
 * @file
 * Define Pick-pack pont Pane to checkout process.
 */

/**
 * Pick-pack pont Pane: form callback.
 */
function commerce_pickpackpoints_pane_checkout_form($form, &$form_state, $checkout_pane, $order) {
  if (!commerce_pickpackpoints_shipping_is_pickpackpoints($order)) {
    // No pick-pack shipping.
    $order = commerce_order_status_update($order, 'checkout_' . $form_state['checkout_page']['next_page']);
    drupal_goto(commerce_checkout_order_uri($order));
  }

  $lists = commerce_pickpackpoints_get_lists();
  $county = -1;
  $city = -1;
  $shop = -1;

  $form['county'] = array(
    '#type' => 'select',
    '#title' => t('County'),
    '#default_value' => $county,
    '#options' => $lists['pp_county'],
    '#attributes' => array(
      'id' => "counties",
      'onchange' => "ChangeCountyList();",
    ),
  );
  $form['city'] = array(
    '#type' => 'select',
    '#title' => t('City'),
    '#default_value' => $city,
    '#options' => $lists['pp_city'],
    '#attributes' => array(
      'id' => "cities",
      'onchange' => "ChangeCityList();",
    ),
  );
  $form['shop'] = array(
    '#type' => 'select',
    '#title' => t('Shop'),
    '#default_value' => $shop,
    '#options' => $lists['pp_list'],
    '#attributes' => array(
      'id' => "shops",
      'onchange' => "ChangeShopList();",
    ),
    '#required' => TRUE,
  );

  $form['shop_info'] = array(
    '#markup' => '',
    '#prefix' => '<div id="pickpack-text">',
    '#suffix' => '</div>',
  );

  // Need on page load to reset select elements.
  drupal_add_js("PickPackRemoveOptions($county, $city, $shop);", array('type' => 'inline', 'scope' => 'footer'));

  return $form;
}

/**
 * Pick-pack pont pane: validation callback.
 */
function commerce_pickpackpoints_pane_checkout_form_validate($form, &$form_state, $checkout_pane, $order) {
  $shop_id = $form_state['values'][$checkout_pane['pane_id']]['shop'];
  if ($shop_id < 0) {
    form_set_error($checkout_pane['pane_id'] . '][shop', t('Please choose a shop.'));
    return FALSE;
  }
  return TRUE;
}

/**
 * Pick-pack pont pane: checkout form submission callback.
 */
function commerce_pickpackpoints_pane_checkout_form_submit($form, &$form_state, $checkout_pane, $order) {
  if (!empty($form_state['values'][$checkout_pane['pane_id']])) {
    $pane_values = $form_state['values'][$checkout_pane['pane_id']];
    $order->data['pick_pack_shop'] = $pane_values['shop'];
    if (module_exists('commerce_pickpackpoints_field')) {
      $order->pickpack_field_pickpack[LANGUAGE_NONE][0]['value'] = $pane_values['shop'];
    }
  }
}

/**
 * Pick-pack pont pane.
 *
 * Presents the information we've collected in the Review checkout pane.
 */
function commerce_pickpackpoints_pane_review($form, $form_state, $checkout_pane, $order) {
  if (!commerce_pickpackpoints_shipping_is_pickpackpoints($order)) {
    return '';
  }
  $data = commerce_pickpackpoints_get_data();
  $content['nickname'] = array(
    '#type' => 'item',
    '#title' => t('Products delivery to Pick-pack pont') . ':',
    '#markup' => commerce_pickpackpoints_get_rendered_data($order->data['pick_pack_shop'], $data[$order->data['pick_pack_shop']]),
  );
  return drupal_render($content);
}
